#
# spec file for package adcli
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define filehash ea560656ac921b3fe0d455976aaae9be
%define sighash 429430e8cf4ddac8a95fb90379adc120
Name:           adcli
Version:        0.9.2
Release:        1.10
Summary:        Tool for performing actions on an Active Directory domain
License:        LGPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://gitlab.freedesktop.org/realmd/adcli
Source0:        https://gitlab.freedesktop.org/realmd/adcli/uploads/%{filehash}/%{name}-%{version}.tar.gz
Source2:        https://gitlab.freedesktop.org/realmd/adcli/uploads/%{sighash}/%{name}-%{version}.tar.gz.sig
# https://keys.openpgp.org/vks/v1/by-fingerprint/287939DF062AD8C53876A535C2D7B98A934EEC17
Source3:        %{name}.keyring
BuildRequires:  automake
BuildRequires:  libxslt-tools
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  pkgconfig(mit-krb5)

%description
A command line tool that can perform actions in an Active Directory domain.
Among other things it can be used to join a computer to a domain.

%package doc
Summary:        Documentation for adcli
Group:          Documentation/Other
BuildArch:      noarch

%description doc
A command line tool that can perform actions in an Active Directory domain.
Among other things it can be used to join a computer to a domain.

This package contains the documentation for adcli.

%prep
%autosetup -p1

%build
%configure \
	--disable-static \
	--disable-silent-rules \
	--enable-strict
%make_build

%install
%make_install
# Remove zero-length file.
rm %{buildroot}/%{_datadir}/doc/%{name}/adcli-docs.proc

%check
%make_build check

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_sbindir}/%{name}
%{_mandir}/man8/adcli.8%{?ext_man}

%files doc
%license COPYING
%doc %{_datadir}/doc/%{name}

%changelog
* Thu Dec 29 2022 Matthias Eliasson <elimat@opensuse.org>
- Update to 0.9.2:
  * adenroll: set password via LDAP instead Kerberos
  * disco: fall back to LDAPS if CLDAP ping was not successful
  * tools: replace getpass()
  * adenroll: write SID before secret to Samba's db
  * doc: add clarification to add-member command on doc/adcli.xml
  * tools: Set umask before calling mkdtemp()
  * Avoid undefined behaviour in short option parsing
  * library: include endian.h for le32toh
  * man: Fix typos and use consistent upper case for some keywords
  * doc: avoid gnu-make specific usage of $<
  * configure: check for ns_get16 and ns_get32 as well
  * Add setattr and delattr options
  * entry: add passwd-user sub-command
  * Add dont-expire-password option
  * build: add --with-vendor-error-message configure option
- Remove patch fixed upstream: 0001-configure-check-for-ns_get16-and-ns_get32-as-well.patch
- Update signing key for source validation
* Fri Aug 13 2021 Samuel Cabrero <scabrero@suse.de>
- Fix build with glibc 2.34; (bsc#1189080); Add patch
  0001-configure-check-for-ns_get16-and-ns_get32-as-well.patch
* Mon Mar 22 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.9.1:
  * tools: add show-computer command
  * add description option to join and update
  * Use GSS-SPNEGO if available
  * add option use-ldaps
  * tools: disable SSSD's locator plugin
  * doc: explain required AD permissions
  * computer: add create-msa sub-command
  * Add account-disable option
  * fix coredump in discovery (boo#1183870)
- use upstream bootstrapped tarball
- add upstream signing key and validate source signature
- use strict build
- run tests
* Wed Nov 20 2019 Samuel Cabrero <scabrero@suse.de>
- Update to version 0.9.0+git.0.1b15280:
  * Release version 0.9.0
  * doc: add missing samba_data_tool_path.xml(.in) to EXTRA_DIST
  * doc: explain how to force password reset
  * Do not use arcfour-hmac-md5 when discovering the salt
  * Fix for issue found by Coverity
  * adenroll: use only enctypes permitted by Kerberos config
  * adenroll: add adcli_enroll_get_permitted_keytab_enctypes with tests
  * adconn: add adcli_conn_set_krb5_context
  * adenroll: make sure only allowed enctypes are used in FIPS mode
  * tools: computer - remove errx from parse_option
* Tue Oct  2 2018 Jan Engelhardt <jengelh@inai.de>
- Make doc noarch and stop requiring packages that are not
  technically needed.
* Mon Oct  1 2018 Ismail Dönmez <idonmez@suse.com>
- Run spec-cleaner
* Fri Sep 21 2018 ckowalczyk@suse.com
- Initial build.
